CREATE TABLE IF NOT EXISTS public.flows_channel
(
    channel_id serial,
    channel_name character varying(100) COLLATE pg_catalog."default" NOT NULL,
    channel_protocol character varying(20) COLLATE pg_catalog."default" DEFAULT 'sflow'::character varying,
    channel_port integer NOT NULL,
    channel_ip_dist inet NOT NULL,
    channel_delete boolean DEFAULT false,
    CONSTRAINT flows_channel_pkey PRIMARY KEY (channel_id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE IF EXISTS public.flows_channel  OWNER to esia;

CREATE TABLE IF NOT EXISTS public.flows_collector_plugins
(
    plugin_id serial,
    plugin_name character varying(50) COLLATE pg_catalog."default" NOT NULL,
    plugin_path character varying(200) COLLATE pg_catalog."default",
    plugin_interval interval NOT NULL,
    plugin_delete boolean DEFAULT false,
    plugin_parameter character varying(100) COLLATE pg_catalog."default",
    CONSTRAINT flows_script_stats_pkey PRIMARY KEY (plugin_id)
)
WITH (
    OIDS = FALSE
);
ALTER TABLE IF EXISTS public.flows_collector_plugins OWNER to esia;
CREATE TABLE IF NOT EXISTS public.flows_collector
(
    collector_id bigserial,
    collector_name character varying(50) COLLATE pg_catalog."default",
    collector_parameter character varying(200) COLLATE pg_catalog."default",
    collector_last_execution timestamp with time zone,
    collector_plugin_id integer,
    collector_channel_id integer,
    collector_delete boolean DEFAULT false,
    collector_state integer DEFAULT 0,
    collector_message text COLLATE pg_catalog."default",
    collector_retention_day integer DEFAULT 30,
    CONSTRAINT flow_collector_pkey PRIMARY KEY (collector_id),
    CONSTRAINT "collector_foreignKey_channel_id" FOREIGN KEY (collector_channel_id)
        REFERENCES public.flows_channel (channel_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT "collector_foreignKey_plugin_id" FOREIGN KEY (collector_plugin_id)
        REFERENCES public.flows_collector_plugins (plugin_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
);

ALTER TABLE IF EXISTS public.flows_collector OWNER to esia;
CREATE TABLE IF NOT EXISTS public.flows_updel_collector
(
    updel_collector_id bigint NOT NULL,
    updel_collector_type character varying COLLATE pg_catalog."default" DEFAULT 'UPDATE'::character varying,
    CONSTRAINT flows_updel_collector_pkey PRIMARY KEY (updel_collector_id)
)
WITH (
    OIDS = FALSE
);

ALTER TABLE IF EXISTS public.flows_updel_collector OWNER to esia;
CREATE TABLE IF NOT EXISTS public.flows_stats
(
    stat_id bigserial,
    stat_time timestamp with time zone NOT NULL DEFAULT now(),
    stat_data json,
    stat_collector_id bigint,
    CONSTRAINT flows_stats_pkey PRIMARY KEY (stat_id),
    CONSTRAINT "flows_stats_foreignKey_collector_id" FOREIGN KEY (stat_collector_id)
        REFERENCES public.flows_collector (collector_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
)
WITH (
    OIDS = FALSE
);

ALTER TABLE IF EXISTS public.flows_stats
    OWNER to esia;
-- Index: fki_flows_stats_foreignKey_collector_id

-- DROP INDEX IF EXISTS public."fki_flows_stats_foreignKey_collector_id";

CREATE INDEX IF NOT EXISTS "fki_flows_stats_foreignKey_collector_id"
    ON public.flows_stats USING btree
    (stat_collector_id ASC NULLS LAST)
;
--TRAFFIC
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TRAFFIC_BYTES_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-traffic');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TRAFFIC_BYTES_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-traffic');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TRAFFIC_BYTES_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-traffic');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TRAFFIC_BYTES_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-traffic');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TRAFFIC_BYTES_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-traffic');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TRAFFIC_BYTES_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-traffic');

--TOP IP BYTES
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i  1440 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes');

--TOP IP BYTES UPLOAD
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_UPLOAD_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_UPLOAD_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_UPLOAD_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_UPLOAD_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i  1440 -t ip-bytes-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_UPLOAD_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_UPLOAD_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-upload');

--TOP IP BYTES DOWNLOAD
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_DOWNLOAD_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_DOWNLOAD_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_DOWNLOAD_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_DOWNLOAD_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i  1440 -t ip-bytes-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_DOWNLOAD_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_DOWNLOAD_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-download');

--TOP IP BYTES
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i  1440 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes');


--TOP IP BYTES PUBLIC
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-public');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-public');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-public');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-bytes-public');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-public');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-public');

--TOP IP BYTES PUBLIC DOWNLOAD
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_DOWNLOAD_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-public-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_DOWNLOAD_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-public-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_DOWNLOAD_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-public-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_DOWNLOAD_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-bytes-public-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_DOWNLOAD_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-public-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_DOWNLOAD_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-public-download');

--TOP IP BYTES PUBLIC UPLOAD
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_UPLOAD_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-public-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_UPLOAD_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-public-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_UPLOAD_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-public-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_UPLOAD_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-bytes-public-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_UPLOAD_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-public-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_PUBLIC_UPLOAD_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-public-upload');

--TOP IP BYTES LAN
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-lan');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-lan');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-lan');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-bytes-lan');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-lan');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-lan');


--TOP IP BYTES LAN UPLOAD

INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_UPLOAD_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-lan-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_UPLOAD_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-lan-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_UPLOAD_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-lan-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_UPLOAD_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-bytes-lan-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_UPLOAD_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-lan-upload');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_UPLOAD_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-lan-upload');


--TOP IP BYTES LAN DOWNLOAD
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_DOWNLOAD_15MIN','/usr/local/esiaCollector/plugins/top_ip.php','5min','-c $CHANNEL -n 10 -i 15 -t ip-bytes-lan-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_DOWNLOAD_1H','/usr/local/esiaCollector/plugins/top_ip.php','15min','-c $CHANNEL -n 10 -i 60 -t ip-bytes-lan-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_DOWNLOAD_6H','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 360 -t ip-bytes-lan-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_DOWNLOAD_1D','/usr/local/esiaCollector/plugins/top_ip.php','30min','-c $CHANNEL -n 10 -i 1440 -t ip-bytes-lan-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_DOWNLOAD_7D','/usr/local/esiaCollector/plugins/top_ip.php','6hours','-c $CHANNEL -n 10 -i 10080 -t ip-bytes-lan-download');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_IP_BYTES_LAN_DOWNLOAD_30D','/usr/local/esiaCollector/plugins/top_ip.php','1days','-c $CHANNEL -n 10 -i 43200 -t ip-bytes-lan-download');

--PORT
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_PORT_15MIN','/usr/local/esiaCollector/plugins/top_port.php','5min','-c $CHANNEL -n 10 -i 15 -t port');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_PORT_1H','/usr/local/esiaCollector/plugins/top_port.php','15min','-c $CHANNEL -n 10 -i 60 -t port');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_PORT_6H','/usr/local/esiaCollector/plugins/top_port.php','30min','-c $CHANNEL -n 10 -i 360 -t port');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_PORT_1D','/usr/local/esiaCollector/plugins/top_port.php','30min','-c $CHANNEL -n 10 -i 1440 -t port');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_PORT_7D','/usr/local/esiaCollector/plugins/top_port.php','6hours','-c $CHANNEL -n 10 -i 10080 -t port');
INSERT INTO flows_collector_plugins(plugin_id, plugin_name, plugin_path, plugin_interval, plugin_parameter)
VALUES (DEFAULT,'TOP_10_PORT_30D','/usr/local/esiaCollector/plugins/top_port.php','1days','-c $CHANNEL -n 10 -i 43200 -t port');


INSERT INTO public.flows_collector(collector_plugin_id,collector_name, collector_parameter, collector_channel_id)
SELECT plugin_id, plugin_name,plugin_parameter,NULL as channel
FROM flows_collector_plugins;
