<?php
/**
 * @name Model_esia
 * @description Classe modèle d'Esia
 *		Toutes les méthodes sont déclarée en 'static' ainsi on garde les Objets PDO pour les programmeurs extérieurs et pour faire des modifications, ils ne sont pas /
 *		obligé de connaitre la hierachie de classe d'ESIA
 * @author Nicolas Biersart <n.biersart@esia-network.com>
 * @contributor
 * @copyright Nicolas Biersart 2012
 * @license
 * @esia 1.00
 * @version 1.0.0
 * @date 16/11/2012
 */

class Model_flows_collector
{
	/**
	 * exécute une requete préparée et traite l'erreur
	 * @param PDOStatement $query un objet PDOStatement (requête préparée)
	 * @param array  $param $param les paramètres à passer à la requête (voir PDOStatement::execute())
	 * @throws EsiaDbException
	 * @retval PDOStatement un objet PDOStatement qui a été exécuté
	 */
	static function executeStatement(PDOStatement $query,$param=NULL)
	{
		$ret = $query->execute($param);
		if($ret === FALSE)
		{
			$err = $query->errorInfo();
			throw new Exception($err[2]);
		}
		return $query;
	}
	static function getChannels($dbconnection,$channel_id=null)
	{
        $sql = "SELECT channel_id, channel_name, channel_protocol, channel_port, channel_ip_dist
				FROM flows_channel";
		$sqlcount= "SELECT count(*) as collector
					FROM flows_collector
					WHERE collector_channel_id=?;";
        $params= array();
        if(!empty($channel_id))
        {
            if(is_numeric($channel_id))
            {
                $sql .= " WHERE channel_id = :id";
                $params[':id']= $channel_id;
            }
            else
            {
                $sql .= " WHERE channel_name = :name";
                $params[':name']= $channel_id;
            }
        }
      //  echo $sql;
		$query = $dbconnection->prepare($sql);
		$querycount = $dbconnection->prepare($sqlcount);
		$query = Model_flows_collector::executeStatement($query,$params);
        $arr = array();
		while($row = $query->fetch(PDO::FETCH_OBJ))
		{
            $count = Model_flows_collector::executeStatement($querycount,array($row->channel_id));
            $countCollector = $count->fetch(PDO::FETCH_OBJ);
            $arr[$row->channel_id] = array('id'=>  $row->channel_id,
                'name'=>  $row->channel_name,
                'protocol'=>  $row->channel_protocol,
                'port'=>  $row->channel_port,
                'ip_dist'=>  $row->channel_ip_dist,
                'collectorNumber'=>  $countCollector->collector
                );
        }
        return $arr;
	}
 	static function getCollectors($dbconnection,$colid=null,$channel_id=-1)
	{
        $sql = "SELECT collector_id,collector_name, collector_parameter,collector_last_execution,collector_state,collector_message,collector_channel_id,EXTRACT(EPOCH FROM plugin_interval) as interval
                FROM flows_collector
                JOIN flows_collector_plugins ON collector_plugin_id= plugin_id";
        $sqlcount= "SELECT count(*) as number
					FROM flows_stats
					WHERE stat_collector_id=?;";
        $params= array();
        if(!empty($colid))
        {
            if(is_numeric($colid))
            {
                $sql .= " WHERE collector_id = :id";
                $params[':id']= $colid;
            }
            elseif(empty($channel_id))
		    {
		    	$sql .= " WHERE collector_name = :name AND collector_channel_id IS NULL";
		        $params[':name']= $colid;
		    }
            else
            {
                $sql .= " WHERE collector_name = :name AND collector_channel_id = :channelid";
                $params[':channelid']= $channel_id;
                $params[':name']= $colid;
            }
        }
        elseif(empty($channel_id))
        {
                $sql .= " WHERE collector_channel_id IS NULL";
        }
        elseif($channel_id != -1 )
        {
                $sql .= " WHERE collector_channel_id = :channelid";
                $params[':channelid']= $channel_id;
        }
      //  echo $sql;
		$query = $dbconnection->prepare($sql);
		$querycount = $dbconnection->prepare($sqlcount);
		$query = Model_flows_collector::executeStatement($query,$params);
        $arr = array();
        $list_id=array();
		while($row = $query->fetch(PDO::FETCH_OBJ))
		{
		    $count = Model_flows_collector::executeStatement($querycount,array($row->collector_id));
            $countStat = $count->fetch(PDO::FETCH_OBJ);
            $list_id[] = $row->collector_id;
            $arr[$row->collector_id] = array('id'=>  $row->collector_id,
                'name'=>  $row->collector_name,
                'parameter'=>  $row->collector_parameter,
                'last_execution'=>  $row->collector_last_execution,
                'state'=>  $row->collector_state,
                'message'=>  $row->collector_message,
                'channel'=>  $row->collector_channel_id,
                'number'=> $countStat->number,
                'interval'=> $row->interval,
                'data'=>  array());
        }
        $data=array();
       // echo count($list_id);
        if(count($list_id)!=0)
        {
			$data =  Model_flows_collector::getData($dbconnection,$list_id);
			foreach($data as $key => $line)
		    {
		        $arr[$key]['data']=$line[0];
		    }
        }
        return $arr;
	}
 	static function getData($dbconnection,$colid,$dataid='last')
	{
        $params= array();
        $sql = "SELECT stat_id, stat_time, stat_data, stat_collector_id
                FROM flows_stats";
        if($dataid == 'last')
        {
            $sql .= " WHERE stat_id = (SELECT MAX(stat_id) FROM flows_stats ";
            if(is_array($colid))
            {
			    foreach($colid as $id)
			    {
				    if(!is_numeric($id)) {
					    throw new EsiaDbException('$colid must be numeric');
				    }
			    }
                $arrids = implode(",",$colid);
                $sql .=" WHERE stat_collector_id IN ( $arrids ) )";
            }
            else
            {
                $sql .=" WHERE stat_collector_id = :id";
                $params[':id']= $colid;
            }
        }
        elseif(is_numeric($dataid))
        {
			$sql .=" WHERE stat_collector_id = :id AND stat_id=:stat";
            $params[':id']= $colid;
            $params[':stat']= $dataid;
        }
        else
        {
			$sql .=" WHERE stat_collector_id = :id";
            $params[':id']= $colid;
        }
       //echo " ".$sql . " OD".$colid;
		$query = $dbconnection->prepare($sql);
		$query = Model_flows_collector::executeStatement($query,$params);
        $arr = array();
		while($row = $query->fetch(PDO::FETCH_OBJ))
		{
            $arr[$row->stat_collector_id][] = array('id'=>$row->stat_id,'time'=>$row->stat_time,'data'=> json_decode($row->stat_data,true));
           /* if(array_key_exists($row->,$arr))
            {

            }
            else
            {

            }*/
        }
        return $arr;
	}
 	static function getCollectorsPlugin($dbconnection,$colid=null)
	{
        $sql = "SELECT plugin_id, plugin_name, plugin_path, plugin_interval, plugin_delete, plugin_parameter,plugin_retention_day,EXTRACT(EPOCH FROM plugin_interval) as intervalsecond
	            FROM flows_collector_plugins ";
        $params= array();
        if(!empty($colid))
        {
            if(is_numeric($colid))
            {
                $sql .= " WHERE plugin_id = :id";
                $params[':id']= $colid;
            }
            elseif(empty($channel_id))
		    {
		    	$sql .= " WHERE plugin_name = :name";
		        $params[':name']= $colid;
		    }
        }
		$query = $dbconnection->prepare($sql);
		$query = Model_flows_collector::executeStatement($query,$params);
        $arr = array();
		while($row = $query->fetch(PDO::FETCH_OBJ))
		{
            $arr[$row->plugin_id] = array('id'=>  $row->plugin_id,
                'name'=>  $row->plugin_name,
                'parameter'=>  $row->plugin_parameter,
                'path'=>  $row->plugin_path,
                'delete'=>  $row->plugin_delete,
                'interval'=> $row->plugin_interval,
                 'interval_second'=> $row->intervalsecond,
                'retentionday'=>$row->plugin_retention_day);
        }
        return $arr;
	}
	static function addCollector($dbconnection,$name,$param,$plugind,$channel)
	{
		$sql ="INSERT INTO flows_collector (collector_id,collector_name,collector_parameter,collector_plugin_id,collector_channel_id)
				VALUES (DEFAULT,:name,:param,:plugin:,:channel);";
		$params['name'] = $name;
		$params['param'] = $param;
		$params['plugin'] = $plugind;
		$params['channel'] = $channel;
		$query = $dbconnection->prepare($sql);
		$query = Model_flows_collector::executeStatement($query,$params);
	}
	static function addChannel($dbconnection,$name,$protocol,$port,$ip)
	{
		$sql ="INSERT INTO flows_channel (channel_id,channel_name,channel_protocol,channel_port,channel_ip_dist)
				VALUES (DEFAULT,:name,:proto,:port:,:ip_dist);";
		$params['name'] = $name;
		$params['proto'] = $protocol;
		$params['port'] = $port;
		$params['ip'] = $ip;
		$query = $dbconnection->prepare($sql);
		$query = Model_flows_collector::executeStatement($query,$params);
	}
}
?>
